-----------------------
-- Private functions --
-----------------------

-- GR_GetGR(unitID)
---> params:
--[[
    same as GR_GetGearRating() but without checks on the unitID
  ]]
---> returns
--[[
    same as GR_GetGearRating() but without checks on the unitID
  ]]
function GR_GetGR(unitID)
    -- Init
    til = 0;
    ail = { 0, 0, 0, 0, 0, 0, 0 };
    tcil1 = 0;
    acil1 = { 0, 0, 0, 0, 0, 0, 0 };
    tcil2 = 0;
    acil2 = { 0, 0, 0, 0, 0, 0, 0 };

    -- Loop
    for i=1,18 do
    
        -- skip "shirt"
        if i < 4 or i > 4 then
        
            l = GetInventoryItemLink(unitID, i)
            if l then
                itemName, itemLink, itemRarity, il, itemMinLevel, itemType, itemSubType, itemStackCount, itemEquipLoc = GetItemInfo(l);
                
                -- skip items with itemLevel 0, example: "Insignia of the Alliance"
                if il and il > 0 then
                    -- compensatie for 1-indexed arrays (itemRarity is 0-indexed)
                    itemRarity = itemRarity + 1;
                    
                    -- til/AIL
                    -- keep track of total itemLevel per quality (and thus keep track of til)
                    ail[itemRarity] = ail[itemRarity] + il;
                    til = til + il;
                    
                    -- CIL1
                    -- compensate item-level for quality
                    cil1 = (il - GR_Subtract[itemRarity]) * GR_Factor[itemRarity];
                    
                    -- tcil1/ACIL1
                    tcil1 = tcil1 + cil1;
                    acil1[itemRarity] = acil1[itemRarity] + cil1;
                    
                    -- CIL2
                    -- compensate item-level for slot-index
                    cil2 = cil1 * GR_SlotFactor[i];
                    if i > 15 then
                        -- use GR_WeaponFactor too
                        cil2 = cil2 * GR_WeaponFactor[GR_WeaponStrToInt(itemEquipLoc)];
                    end
                    if i == 18 then
                        -- compensate for hunter's ranged weapon too
                        localizedClass, englishClass = UnitClass(unitID);
                        if englishClass == "HUNTER" then
                            cil2 = cil2 * GR_HunterRangedFactor
                        end
                    end
                    
                    -- tcil2/ACIL2
                    tcil2 = tcil2 + cil2;
                    acil2[itemRarity] = acil2[itemRarity] + cil2;
                    
                end
            end
        end
    end

    return math.floor(tcil2), math.floor(til), ail, math.floor(tcil1), acil1, math.floor(tcil2), acil2;
end

function GR_GetIR(itemLevel, itemRarity, slotFactorIndex, weaponFactorIndex, useHunterFactor)
    -- compensatie for 1-indexed arrays (itemRarity is 0-indexed)
    itemRarity = itemRarity + 1;
    
    -- CIL1
    -- compensate item-level for quality
    cil1 = (itemLevel - GR_Subtract[itemRarity]) * GR_Factor[itemRarity];
    
    -- CIL2
    -- compensate item-level for slot-index
    cil2 = cil1 * GR_SlotFactor[slotFactorIndex];
    if slotFactorIndex > 15 then
        -- use GR_WeaponFactor too
        cil2 = cil2 * GR_WeaponFactor[weaponFactorIndex];
    end
    if slotFactorIndex == 18 then
        if useHunterFactor then
            cil2 = cil2 * GR_HunterRangedFactor
        end
    end
    
    GR_Debug("---> IL: "..itemLevel.." ("..GR_String[itemRarity]..")");
    GR_Debug("---> CIL1: "..cil1);
    GR_Debug("---> CIL2: "..cil2);
    
    return nil;
end
