-----------------
-- Definitions --
-----------------
--[[
GR     = GearRating

IL     = ItemLevel
TIL    = Total Item Level (sum of all IL)
AIL    = Array of IL per quality (poor, common, uncommon, rare, epic, legendary, artifact), 

CIL1   = IL compensated for item quality (epic, rare, uncommon, etc.)
TCIL1  = sum of all CIL1
ACIL1  = Array of CIL1 per quality (poor, common, uncommon, rare, epic, legendary, artifact), 

CIL2   = CIL1 compensatied for item slot (head, chest, feet, etc.)
TCIL2  = sum of all CIL2,   IN THE CURRENT VERSION, THIS IS YOUR GR!    (TCIL2 == GR)
ACIL2  = Array of CIL2 per quality (poor, common, uncommon, rare, epic, legendary, artifact), 
  ]]


-- Colors
GR_White = "|cffffffff";
GR_Blue = "|cff0000ff";
GR_Purple = "|cffff00ff";
GR_Red = "|cffff0000";
GR_Yellow = "|cffffff00";

-- Name
function GR_Bracketed()
    return "("..GearRating.name.." v"..GearRating.version.." -Ace2-)";
end

-- Party Header/Footer
function GR_PartyHeader()
    return GearRating.name.." Party Report:";
end
function GR_PartyFooter()
    return "Average Party GR: ";
end

---------------------------------------
-- chars that are used in the TILstr --
---------------------------------------

GR_Char = {
    -- poor
    "p",
    -- common
    "c",
    -- uncommon
    "u",
    -- rare
    "r",
    -- epic
    "e",
    -- legendary
    "l",
    -- artifact
    "a" };

GR_String = {
    "poor",
    "common",
    "uncommon",
    "rare",
    "epic",
    "legendary",
    "artifact" };

-------------------------------------------------
-- values used to calculate CIL1 ----------------
-------------------------------------------------
------------------- based on: -------------------
-- http://www.wowwiki.com/Formulas:Item_Values --
-------- Calculating item level section ---------
-------------------------------------------------

GR_Subtract = {
    -- poor
    0,
    -- common
    0,
    -- uncommon
    4.00,
    -- rare
    1.84,
    -- epic
    1.30,
    -- legendary
    0,
    -- artifact
    0 };
    
GR_Factor = {
    -- poor ( poor items are worth 0 )
    0,
    -- common ( common items are worth 0 )
    0,
    -- uncommon ( div 2 == * 0,5 )
    0.5,
    -- rare ( div 1.6 == * 0.625 )
    0.625,
    -- epic ( div 1.3 == * 0.625 )
    0.7692,
    -- legendary ( legendary items are not compensated )
    1,
    -- artifact ( artifact items are not compensated )
    1 };
    
-------------------------------------------------
-- values used to calculate CIL2 ----------------
-------------------------------------------------
------------------- based on: -------------------
-- http://www.wowwiki.com/Formulas:Item_Values --
------------ Slot modifiers section -------------
-------------------------------------------------

GR_SlotFactor = {
    -- head (1)
    1,
    -- neck (2)
    0.55,
    -- shoulder (3)
    0.777,
    -- shirt (4)
    0,
    -- chest (5)
    1,
    -- waist (6)
    0.777,
    -- legs (7)
    1,
    -- feet (8)
    0.777,
    -- wrist (9)
    0.55,
    -- hand (10)
    0.777,
    -- finger 1 (11)
    0.55,
    -- finger 2 (12)
    0.55,
    -- trinket 1 (13)
    0.70,
    -- trinket 2 (14)
    0.70,
    -- back (15)
    0.55,
    -- weapon (16) (this value has to be 1, because GR_WeaponFactor is used after)
    1,
    -- off hand (17) (this value is combined with the value in GR_WeaponFactor) (note: this value is estimated by the author)
    0.777,
    -- ranged weapon (18) (this value has to be 1, because GR_WeaponFactor is used after)
    1 };

-----------------------------------------------
-- values used to calculate CIL2 --------------
-----------------------------------------------
------------------ based on: ------------------
-- own estimation (so subject to discussion) --
-----------------------------------------------

-- Equipment slot
        -- justification
    -- value

GR_WeaponFactor = {
    -- Main Hand weapon (1)
            -- a weapon is as important as a chest/helm/legs
        1,
    -- Off-hand weapon (2)
            -- an off-hander usually does less damage, however, this is already compensated by GR_SlotFactor
        1,
    -- One-hand weapon (3)
            -- value is determined by GR_SlotFactor
        1,
    -- 2h weapon (4)
            -- a 2h weapon is nearly twice (1.6 < 1 + 0.7) as important as a main-hand weapon + an off-hand weapon
        1.67,
    -- Shield (5)
            -- considered about as important as a belt/gloves/shoulders/boots, however, is already influenced by off-hand penalty
        1,
    -- Bow/Crossbow/Gun (6) Hunter/Rogue/Warrior
            -- a warrior/rogue mainly uses a ranged weapon to pull/kite. the strength of the weapon is therefore quite irrelevant
            -- the ranged weapon is considered just a stat-booster: a ring (0.55)
            -- however, for hunters the weapon is very important, and compensated by GR_HunterRangedFactor (0.55 * 2.75 =~ 1.5)
        0.55,
    -- Thrown weapon (7) Hunter/Rogue/Warrior
            -- same as Bow/Crossbow/Gun, but Thrown weapons are a bit less important (0.50 * 2.30 = 1.15)
        0.50,
    -- Wand (8) Priest/Mage/Warlock
            -- considered a Bow/Crossbow/Gun
        0.55,
    -- Held in off-hand (9)
            -- considered as another ring, influenced by off-hand penalty (0.7 * 0.777 =~ 0.55
        0.7,
    -- Relic (10) Druid (Idol) / Shaman (Totem) / Paladin (Libram) / Warlock (Spellstone)
            -- considered as another ring
        0.55 };
        
GR_HunterRangedFactor = 2.75;

-----------------------------------------------------------------------------------
-- function to convert itemEquipLoc (from GetItemInfo) to integer in above array --
-----------------------------------------------------------------------------------
function GR_WeaponStrToInt(str)
    if str == "INVTYPE_WEAPONMAINHAND" then
        return 1;
    elseif str == "INVTYPE_WEAPONOFFHAND" then
        return 2;
    elseif str == "INVTYPE_WEAPON" then
        return 3;
    elseif str == "INVTYPE_2HWEAPON" then
        return 4;
    elseif str == "INVTYPE_SHIELD" then
        return 5;
    elseif str == "INVTYPE_RANGED" then
        return 6;
    elseif str == "INVTYPE_THROWN" then
        return 7;
    elseif str == "INVTYPE_RANGEDRIGHT" then
        return 8;
    elseif str == "INVTYPE_HOLDABLE" then
        return 9;
    elseif str == "INVTYPE_RELIC" then
        return 10;
    else
        return -1;
    end
end

