-----------------
-- Ace2 Locale --
-----------------
local L = AceLibrary("AceLocale-2.2"):new("GearRating")


-----------------------------
-- Main Handling functions --
-----------------------------
function GR_Handle(src, chatType, target)
    if src == "party" then

        if chatType == "SELF" then
        
            GR_PartyToSelf()
            
        elseif chatType == "TARGET" or chatType == "FOCUS" then
        
            GR_PartyToChannel("WHISPER", UnitName(chatType));
            
        elseif chatType == "WHISPER" then
        
            GR_PartyToChannel(chatType, target);
        
        elseif chatType == "CHANNEL" then    

            id, name = GetChannelName(target);
            if (id > 0 and name ~= nil) then
                GR_PartyToChannel(chatType, id);
            else
                GR_Error(GR_ERROR_NOSUCHCHANNEL, L["No such channel: '"]..target.."'");
            end

        else
        
            GR_PartyToChannel(chatType, nil);
            
        end

    else

        if chatType == "SELF" then
        
            GR_ToSelf(src)
            
        elseif chatType == "TARGET" or chatType == "FOCUS" then
        
            GR_ToChannel(src, "WHISPER", UnitName(chatType));
            
        elseif chatType == "WHISPER" then
        
            GR_ToChannel(src, chatType, target);
        
        elseif chatType == "CHANNEL" then    
        
            id, name = GetChannelName(target);
            if (id > 0 and name ~= nil) then
                GR_ToChannel(src, chatType, id);
            else
                GR_Error(GR_ERROR_NOSUCHCHANNEL, L["No such channel: '"]..target.."'");
            end
        
        else
        
            GR_ToChannel(src, chatType, nil);
            
        end
    end
    
end



---------------------------------------------------
-- Handling of GR commands about a single target --
---------------------------------------------------

function GR_ToSelf(unitID)
    local gr = GR_GetGearRating(unitID)
    
    if gr then
        GR_SendToSelf( GR_LongFormat(unitID, gr) )
    end
end

function GR_ToChannel(unitID, chatType, channel)
    local gr = GR_GetGearRating(unitID)
    
    if gr then
        GR_SendToChannel( GR_LongFormat(unitID, gr), chatType, channel )
    end
end



-----------------------------------------
-- Handling of GR commands about party --
-----------------------------------------

function GR_PartyToSelf()
    GR_SendToSelf( GR_PartyHeader() )
    
    -- party
    local totalgr = 0;
    local nrppl = 0;
    for i=1,4 do
        local gr = GR_GetGearRating("party"..i, true);
        if gr then
            GR_SendToSelf( GR_ShortFormat("party"..i, gr) );
            totalgr = totalgr + gr;
            nrppl = nrppl + 1;
        elseif GR_LASTERROR == GR_ERROR_OUTOFRANGE then
            GR_SendToSelf( GR_ShortFormat("party"..i, "out of range") );
        end            
    end
    -- self
    local gr = GR_GetGearRating("player")
    if gr then
        GR_SendToSelf( GR_ShortFormat("player", gr) )
        totalgr = totalgr + gr;
        nrppl = nrppl + 1;
    end
    
    GR_SendToSelf( GR_PartyFooter() .. math.floor(totalgr / nrppl) .. " " .. GR_Bracketed() )
end

function GR_PartyToChannel(chatType, channel)
    GR_SendToChannel( GR_PartyHeader(), chatType, channel)
    
    -- party
    local totalgr = 0;
    nrppl = 0;
    for i=1,4 do
        local gr = GR_GetGearRating("party"..i, true);
        if gr then
            GR_SendToChannel( GR_ShortFormat("party"..i, gr), chatType, channel );
            totalgr = totalgr + gr;
            nrppl = nrppl + 1;
        elseif GR_LASTERROR == GR_ERROR_OUTOFRANGE then
            GR_SendToChannel( GR_ShortFormat("party"..i, "out of range"), chatType, channel );
        end            
    end
    local gr = GR_GetGearRating("player", true);
    if gr then
        GR_SendToChannel( GR_ShortFormat("player", gr), chatType, channel );
        totalgr = totalgr + gr;
        nrppl = nrppl + 1;
    end            
    
    GR_SendToChannel( GR_PartyFooter() .. math.floor(totalgr / nrppl) .. " " .. GR_Bracketed() , chatType, channel )
end

