-----------------
-- Definitions --
-----------------
--[[
GR     = GearRating

IL     = ItemLevel
TIL    = Total Item Level (sum of all IL)
AIL    = Array of IL per quality (poor, common, uncommon, rare, epic, legendary, artifact), 

CIL1   = IL compensated for item quality (epic, rare, uncommon, etc.)
TCIL1  = sum of all CIL1
ACIL1  = Array of CIL1 per quality (poor, common, uncommon, rare, epic, legendary, artifact), 

CIL2   = CIL1 compensatied for item slot (head, chest, feet, etc.)   (also called IR)
TCIL2  = sum of all CIL2,   IN THE CURRENT VERSION, THIS IS YOUR GR!    (TCIL2 == GR)
ACIL2  = Array of CIL2 per quality (poor, common, uncommon, rare, epic, legendary, artifact), 
  ]]

-----------------
-- Ace2 Locale --
-----------------
local L = AceLibrary("AceLocale-2.2"):new("GearRating")

--------------------------------
-- Public GearRating function --
--------------------------------

-- GR_GetGearRating
---> params:
--[[
    unitID: a unitid as described in http://www.wowwiki.com/UnitId
    silent: optional. If true, do not generate error-messages
  ]]
---> returns:
--[[
    GR: The GearRating of the requested target
        - nil if an error occured
    TIL: see Definitions at the top of this file
    AIL: same
    TCIL1: same
    ACIL1: same
    TCIL2: same
    ACIL2: same
  ]]
function GR_GetGearRating(unitID, silent)
    if UnitExists(unitID) then
    
        if UnitIsPlayer(unitID) then
        
            if UnitIsFriend("player", unitID) then
            
                if CheckInteractDistance(unitID, 1) then
                
                    return GR_GetGR(unitID);
                    
                else
                    GR_Error(GR_ERROR_OUTOFRANGE, "'"..UnitName(unitID).."'"..L[" is out of range."], silent);
                    return nil;
                end
            else
                GR_Error(GR_ERROR_NOTFRIENDLY, "'"..UnitName(unitID).."'"..L[" is not a friendly target."], silent);
                return nil;
            end
        else
            GR_Error(GR_ERROR_NOTPLAYER, "'"..UnitName(unitID).."'".. L[" is not a player."], silent);
            return nil;
        end
    else
        GR_Error(GR_ERROR_NOTEXIST, "'"..unitID.."'".. L[" does not exist."], silent);
        return nil;
    end
end

---------------------------------
-- Public Formatting Functions --
---------------------------------

---> params:
--[[
    ail: Array of Item Levels, an array of 7 numbers.
         - most of the time this will be the AIL, ACIL1 or ACIL2 output from GR_GetGearRating
         - example: { 0, 0, 300, 1500, 110, 0, 0 }
  ]]
---> returns:
--[[
    str: non-colored string in format "<a>a,<l>l,<e>e,<r>r,<u>u,<c>c,<p>p"
          - a value is only present if non-zero
          - example: "110e,1569r,90u"
  ]]
function GR_AILtoStr(ail)
    -- Init
    str = "";
    
    -- Loop through qualities backward
    i = 7;
    while i > 0 do
        if ail[i] > 0 then
            str = str..ail[i]..GR_Char[i]..",";
        end
        i = i - 1;
    end
    
    -- Remove "," at the end
    if string.len(str) > 0 then
        str = string.sub(str, 1, -2);
    end
end

---> params:
--[[
    ail: Array of Item Levels, an array of 7 numbers.
         - most of the time this will be the AIL, ACIL1 or ACIL2 output from GR_GetGearRating
         - example: { 0, 0, 300, 1500, 110, 0, 0 }
  ]]
---> returns:
--[[
    str1: colored string in format "<a>,<l>,<e>,<r>,<u>,<c>,<p>"
          - each item-quality is in it's own color (epic = purple, rare = blue, etc)
          - the comma's are colored red
          - a value is only present if non-zero
          - example: "110,1569,90" (with 110 being purple, 1569 blue and 90 green)
  ]]
function GR_AILtoColorStr(ail)
    -- Init
    str = "";
    
    -- Loop through qualities backward
    i = 7;
    while i > 0 do
        if ail[i] > 0 then
            r, g, b, hex = GetItemQualityColor(i-1);
            -- (- 1 to compensate for 0-indexed array)
            
            str = str..hex..ail[i]..GR_Red..",";
        end
        i = i - 1;
    end
    
    -- Remove "," at the end
    if string.len(str) > 0 then
        str = string.sub(str, 1, -2);
    end
end

